==> haskell-lexer-1.0.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lexer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-lexer
version: 1.0.1
id: haskell-lexer-1.0.1-1drChWRMvNxE3y4irvVxwM
key: haskell-lexer-1.0.1-1drChWRMvNxE3y4irvVxwM
license: BSD3
maintainer: diatchki@galois.com
synopsis: A fully compliant Haskell 98 lexer.
description:
    A fully compliant Haskell 98 lexer.
category: Language
author: Thomas Hallgren
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.Lexer
hidden-modules: Language.Haskell.Lexer.Layout
                Language.Haskell.Lexer.Tokens Language.Haskell.Lexer.Lex
                Language.Haskell.Lexer.Utils Language.Haskell.Lexer.Position
abi: 151474d926785082ca16f89010682aec
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/haskell-lexer-1.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/haskell-lexer-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/haskell-lexer-1.0.1
hs-libraries: HShaskell-lexer-1.0.1-1drChWRMvNxE3y4irvVxwM
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-lexer/html/haskell-lexer.haddock
haddock-html: /usr/share/doc/haskell-lexer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lexer-1.0.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lexer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-lexer
version: 1.0.1
id: haskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3
key: haskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3
license: BSD-3-Clause
maintainer: diatchki@galois.com
author: Thomas Hallgren
synopsis: A fully compliant Haskell 98 lexer.
description:
    A fully compliant Haskell 98 lexer.
category: Language
abi: f7a422a8ef586236d3e005acd1abb1e2
exposed: True
exposed-modules:
    Language.Haskell.Lexer
hidden-modules: Language.Haskell.Lexer.Layout
                Language.Haskell.Lexer.Tokens Language.Haskell.Lexer.Lex
                Language.Haskell.Lexer.Utils Language.Haskell.Lexer.Position
import-dirs: /usr/lib/ghc-8.4.2/site-local/haskell-lexer-1.0.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/haskell-lexer-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/haskell-lexer-1.0.1
hs-libraries: HShaskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
haddock-interfaces: /usr/share/doc/haskell-lexer/html/haskell-lexer.haddock
haddock-html: /usr/share/doc/haskell-lexer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
